@@ -8,12 +8,12 @@ from .TwoSampleHC import binom_test_two_sided
 #from .TwoSampleHC import poisson_test_random
 
 __all__ = [
+	'HC'
     'hc_vals',
     'two_sample_test',
     'two_sample_pvals',
     'binom_test_two_sided_random',
     'binom_test_two_sided',
-    'hc_vals_full',
     'two_sample_test_df',
     'poisson_test_random'
 ]
\ No newline at end of file
